@@ -118,10 +118,13 @@ async def _error_wrapper(func, *, args=(), kwargs=None, retries):
         except ClientError as e:
             logger.debug("Client error (maybe retryable): %s", e)
             err = e
+            wait_time = min(1.7**i * 0.1, 15)
             if "SlowDown" in str(e):
-                await asyncio.sleep(min(1.7**i * 0.1, 15))
+                await asyncio.sleep(wait_time)
+            elif "reduce your request rate" in str(e):
+                await asyncio.sleep(wait_time)
             elif "XAmzContentSHA256Mismatch" in str(e):
-                await asyncio.sleep(min(1.7**i * 0.1, 15))
+                await asyncio.sleep(wait_time)
             else:
                 break
         except Exception as e:
@@ -1951,7 +1954,7 @@ class S3FileSystem(AsyncFileSystem):
             Must have 0 < len <= 1000
         """
         if not pathlist:
-            return
+            return []
         buckets = {self.split_path(path)[0] for path in pathlist}
         if len(buckets) > 1:
             raise ValueError("Bulk delete files should refer to only one bucket")
